import logging
from rdflib import Graph

from cubicweb.appobject import AppObject

from cubicweb_rodolf.process_helpers import (
    get_graph_from_url,
    upload_graph_to_virtuoso_endpoint,
)
from cubicweb_rodolf.schema import ImportProcess


class DefaultProcessType(AppObject):
    __registry__ = "rodolf.appobject.processtype"
    __regid__ = "default"

    def __call__(self, import_process: ImportProcess, log: logging.Logger) -> Graph:
        import_recipe = import_process.import_recipe[0]
        import_procedure = import_process.import_procedure[0]
        dataservice = import_recipe.dataservice[0]
        graph = get_graph_from_url(dataservice.data_url, log)
        dataset_file = import_process.update_dataset(graph)
        upload_graph_to_virtuoso_endpoint(
            import_procedure,
            graph,
            import_recipe.graph_uri,
            dataset_file.data_name,
            log,
        )
        return graph


class DefaultDryRunProcessType(AppObject):
    __registry__ = "rodolf.appobject.processtype"
    __regid__ = "default-dryrun"

    def __call__(self, import_process: ImportProcess, log: logging.Logger) -> Graph:
        import_recipe = import_process.import_recipe[0]
        dataservice = import_recipe.dataservice[0]
        graph = get_graph_from_url(dataservice.data_url, log)
        import_process.update_dataset(graph)
        return graph
