import {
  Dialog,
  DialogTitle,
  DialogContent,
  DialogContentText,
  DialogActions,
  Button,
} from "@mui/material";
import { LoadingButton } from "@mui/lab";
import { useState } from "react";

interface ConfirmModalProps {
  open: boolean;
  text: string;
  onClose: () => void;
  onAccept: () => Promise<void>;
}

export function ConfirmModal({
  open,
  text,
  onClose,
  onAccept,
}: ConfirmModalProps) {
  const [loading, setLoading] = useState(false);

  async function onPressAccept() {
    setLoading(true);
    await onAccept();
    onClose();
    setLoading(false);
  }

  return (
    <Dialog
      open={open}
      onClose={() => {
        if (!loading) {
          onClose();
        }
      }}
      aria-labelledby="alert-dialog-title"
      aria-describedby="alert-dialog-description"
      fullWidth
    >
      <DialogTitle id="alert-dialog-title">Confirmation</DialogTitle>
      <DialogContent>
        <DialogContentText id="alert-dialog-description">
          {text}
        </DialogContentText>
      </DialogContent>
      <DialogActions>
        <Button onClick={onClose} autoFocus disabled={loading}>
          Annuler
        </Button>
        <LoadingButton onClick={onPressAccept} loading={loading}>
          Confirmer
        </LoadingButton>
      </DialogActions>
    </Dialog>
  );
}
