import { AppBar, Box, Button, Stack, Toolbar, Typography } from "@mui/material";
import Link from "next/link";
import Image from "next/image";
import { usePathname } from "next/navigation";
import { useApiLogout } from "@/api/cubicweb";

export function Header() {
  const pathname = usePathname();
  const loggedIn = pathname !== "/login";
  const logout = useApiLogout();

  return (
    <AppBar position="static">
      <Toolbar>
        <Link
          href={"/"}
          prefetch={false}
          style={{
            textDecoration: "none",
            color: "inherit",
          }}
        >
          <Stack
            direction={"row"}
            spacing={2}
            flexGrow={1}
            alignItems={"center"}
          >
            <Image
              src={"/rodolf.jpg"}
              alt={"Rodolf logo"}
              width={50}
              height={50}
            />
            <Typography
              variant="h6"
              sx={{
                display: { xs: "none", sm: "none", md: "block" },
              }}
            >
              Rodolf
            </Typography>
          </Stack>
        </Link>
        <Box flex={1} />
        {loggedIn ? (
          <Button onClick={logout} variant={"contained"} color={"error"}>
            {"Déconnexion"}
          </Button>
        ) : null}
      </Toolbar>
    </AppBar>
  );
}
