import {
  Box,
  CardContent,
  IconButton,
  Stack,
  Typography,
  useTheme,
} from "@mui/material";
import DeleteIcon from "@mui/icons-material/Delete";
import { BaseCard, preventPropagation } from "./BaseCard";
import CheckIcon from "@mui/icons-material/Check";
import CloseIcon from "@mui/icons-material/Close";

interface RecipeCardProps {
  name: string;
  processType: "default" | "default-dryrun";
  lastProcessDate?: Date;
  lastProcessSuccess?: boolean;
  selected: boolean;
  onOpen?: () => void;
  onDelete?: () => void;
}

export function RecipeCard({
  name,
  lastProcessDate,
  lastProcessSuccess,
  processType,
  selected,
  onOpen,
  onDelete,
}: RecipeCardProps) {
  const theme = useTheme();
  return (
    <BaseCard
      onClick={onOpen}
      sx={{
        backgroundColor: selected ? theme.palette.action.selected : undefined,
      }}
    >
      <CardContent>
        <Stack direction={"row"}>
          <Typography variant="h5" component={"p"} fontWeight={"bold"} flex={1}>
            {name}
          </Typography>
          <Box>
            <IconButton
              onClick={(e) => {
                preventPropagation(e);
                if (onDelete) {
                  onDelete();
                }
              }}
              onMouseDown={preventPropagation}
            >
              <DeleteIcon />
            </IconButton>
          </Box>
        </Stack>
        {lastProcessDate && lastProcessSuccess !== undefined ? (
          <>
            <Typography variant="body2">Dernier process</Typography>
            <Stack direction={"row"} spacing={1}>
              <Typography variant="body1">
                {lastProcessDate.toLocaleDateString()}
              </Typography>
              {lastProcessSuccess ? (
                <CheckIcon color="success" />
              ) : (
                <CloseIcon color="error" />
              )}
            </Stack>
          </>
        ) : null}
        <Typography variant="body2">Process type: {processType}</Typography>
      </CardContent>
    </BaseCard>
  );
}
